<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en">
<context>
    <name>DownloadPDBDialog</name>
    <message>
        <location filename="../src/ui/DownloadRemotePDBDialog.ui" line="13"/>
        <source>Download PDB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DownloadRemotePDBDialog.ui" line="19"/>
        <source>Please enter the PDB identifier:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DownloadRemotePDBDialog.ui" line="28"/>
        <source>PDB id:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DownloadRemotePDBDialog.ui" line="55"/>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DownloadRemotePDBDialog.ui" line="62"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ImageExportForm</name>
    <message>
        <location filename="../src/ui/ExportImageDialog.ui" line="14"/>
        <source>Export Image</source>
        <translation>Export image</translation>
    </message>
    <message>
        <location filename="../src/ui/ExportImageDialog.ui" line="32"/>
        <source>File name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportImageDialog.ui" line="44"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportImageDialog.ui" line="59"/>
        <source>Format</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportImageDialog.ui" line="94"/>
        <source>Width</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportImageDialog.ui" line="122"/>
        <location filename="../src/ui/ExportImageDialog.ui" line="169"/>
        <source>px</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportImageDialog.ui" line="141"/>
        <source>Height</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportImageDialog.ui" line="210"/>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ExportImageDialog.ui" line="217"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/BallAndStickGLRenderer.cpp" line="16"/>
        <source>Ball-and-stick</source>
        <translation>Ball-And-Stick</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DColorScheme.cpp" line="14"/>
        <source>chain colors</source>
        <translation>Molecular Chains</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DColorScheme.cpp" line="15"/>
        <source>chemical element colors</source>
        <translation>Chemical Elements</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DColorScheme.cpp" line="16"/>
        <source>secondary structure colors</source>
        <translation>Secondary Structure</translation>
    </message>
    <message>
        <location filename="../src/TubeGLRenderer.cpp" line="11"/>
        <source>Tubes</source>
        <translation>Tubes</translation>
    </message>
    <message>
        <location filename="../src/WormsGLRenderer.cpp" line="22"/>
        <source>Worms</source>
        <translation>Worms</translation>
    </message>
    <message>
        <location filename="../src/VanDerWaalsGLRenderer.cpp" line="26"/>
        <source>Space Fill</source>
        <translation>Space Fill</translation>
    </message>
    <message>
        <location filename="../src/MolecularSurfaceRenderer.cpp" line="7"/>
        <source>Dots</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/MolecularSurfaceRenderer.cpp" line="8"/>
        <source>ConvexMap</source>
        <translation>Convex Map</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/ui/SettingsDialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Settings</translation>
    </message>
    <message>
        <location filename="../src/ui/SettingsDialog.ui" line="17"/>
        <source>10</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/SettingsDialog.ui" line="23"/>
        <source>Set backgroung color</source>
        <translation>Set backgroung color...</translation>
    </message>
    <message>
        <location filename="../src/ui/SettingsDialog.ui" line="30"/>
        <source>Set selection color</source>
        <translation>Set selection color...</translation>
    </message>
    <message>
        <location filename="../src/ui/SettingsDialog.ui" line="37"/>
        <source>Detail level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/SettingsDialog.ui" line="67"/>
        <source>Backplane regions shading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/SettingsDialog.ui" line="80"/>
        <source>Anaglyph view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/SettingsDialog.ui" line="92"/>
        <source>Eyes shift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/SettingsDialog.ui" line="115"/>
        <source>Glasses color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/SettingsDialog.ui" line="130"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/SettingsDialog.ui" line="140"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/SettingsDialog.ui" line="156"/>
        <source>Swap colors</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SplitterHeaderWidget</name>
    <message>
        <source>bs3d_links_file_not_found_%1</source>
        <translation type="obsolete">Links file not found %1</translation>
    </message>
    <message>
        <source>illegal_entry_%1</source>
        <translation type="obsolete">Illegal entry %1</translation>
    </message>
</context>
<context>
    <name>U2::AddModelToSplitterTask</name>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="725"/>
        <source>Add 3d model &apos;%1&apos; to BioStruct3DSplitter</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="753"/>
        <source>Model %1 wasn&apos;t added</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::BioStruct3DGLWidget</name>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="518"/>
        <source>Spin</source>
        <translation>Spin</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="550"/>
        <source>Render style</source>
        <translation>Render style</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="554"/>
        <source>Color Scheme</source>
        <translation>Coloring schema</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="513"/>
        <source>Off</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="522"/>
        <source>Settings</source>
        <translation>Settings...</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="525"/>
        <source>close_action</source>
        <translation>Close</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="528"/>
        <source>Export image</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="532"/>
        <source>Next model</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="535"/>
        <source>Prev model</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="538"/>
        <source>All models</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="558"/>
        <source>Molecular Surface Render Style</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="561"/>
        <source>Molecular Surface</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="566"/>
        <source>Models</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="1139"/>
        <source>Error</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DGLWidget.cpp" line="1139"/>
        <source>Unable to open file %1 for writing</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::BioStruct3DSettingsDialog</name>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="221"/>
        <source>(not supported by your videocard)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::BioStruct3DViewContext</name>
    <message>
        <location filename="../src/BioStruct3DViewPlugin.cpp" line="152"/>
        <source>Close 3D view</source>
        <translation>Close 3D view</translation>
    </message>
</context>
<context>
    <name>U2::BioStruct3DViewPlugin</name>
    <message>
        <location filename="../src/BioStruct3DViewPlugin.cpp" line="59"/>
        <source>biostruct3d_view_plugin</source>
        <translation>BioStruct3D Viewer Plugin</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DViewPlugin.cpp" line="59"/>
        <source>biostruct3d_view_plugin_desc</source>
        <translation>Biological 3D Structure Viewer Description</translation>
    </message>
</context>
<context>
    <name>U2::ExportImageDialog</name>
    <message>
        <location filename="../src/ExportImageDialog.cpp" line="60"/>
        <source>Error</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportImageDialog.cpp" line="60"/>
        <source>The filename is empty!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportImageDialog.cpp" line="68"/>
        <source>Overwrite file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportImageDialog.cpp" line="69"/>
        <source>The file &quot;%1&quot; already exists. Do you wish to overwrite it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ExportImageDialog.cpp" line="108"/>
        <source>Save image to...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ExportImageDialog.cpp" line="76"/>
        <source>Saving image to &apos;%1&apos;...</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::SplitterHeaderWidget</name>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="317"/>
        <source>3D Structure Viewer</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="333"/>
        <source>restore_defaults</source>
        <translation>Restore default view</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="340"/>
        <source>zoom_in</source>
        <translation>Zoom in</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="349"/>
        <source>zoom_out</source>
        <translation>Zoom out</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="356"/>
        <source>Multiple view synchronization lock</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="363"/>
        <source>display</source>
        <translation>Display</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="694"/>
        <source>File not found: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="706"/>
        <source>Illegal entry: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="325"/>
        <source>active_widget:</source>
        <translation>Active view:</translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="476"/>
        <source>show_%1</source>
        <translation>Show %1 </translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="369"/>
        <source>Links</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/BioStruct3DSplitter.cpp" line="375"/>
        <source>Add</source>
        <translation></translation>
    </message>
</context>
</TS>
